NLSL: ordrpr.f90 File Reference

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

Functions/Subroutines
ordrpr.f90 File Reference

Go to the source code of this file.

## Functions/Subroutines
subroutine | ordrpr (cf, d)
double precision function | ftht (ctht)
double precision function | fphi (phi)
double precision function | fu20 (cost)
double precision function | fu20phi (phi)

## Function/Subroutine Documentation

double precision function fphi | ( | double precision | phi | ) |

Definition at line 148 of file ordrpr.f90.

double precision function ftht | ( | double precision | ctht | ) |

Definition at line 98 of file ordrpr.f90.

Here is the call graph for this function:

double precision function fu20 | ( | double precision | cost | ) |

Definition at line 195 of file ordrpr.f90.

double precision function fu20phi | ( | double precision | phi | ) |

Definition at line 209 of file ordrpr.f90.

subroutine ordrpr | ( | double precision, dimension(5) | cf,
|  | double precision, dimension(5) | d
| ) |  |

Definition at line 41 of file ordrpr.f90.

Here is the call graph for this function:

Here is the caller graph for this function: